const path = require('path');
const {CleanWebpackPlugin} = require('clean-webpack-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const RemoveEmptyScriptsPlugin = require('webpack-remove-empty-scripts');

// noinspection JSValidateTypes,JSUnresolvedVariable
module.exports = {

    entry: {
        'hello-elementor': path.resolve(__dirname, 'assets/scss/hello-elementor.scss'),
    },

    output: {
        filename: '[name].js',
        path: path.resolve(__dirname, 'public/dist'),
    },

    plugins: [
        new CleanWebpackPlugin(),
        new RemoveEmptyScriptsPlugin(),
        new CssMinimizerPlugin({
            minimizerOptions: {
                preset: ['default', {
                    discardComments: { removeAll: true },
                }],
            }
        }),
        new MiniCssExtractPlugin({
            filename: 'css/[name].css',
        }),
    ],

    module: {
        rules: [{
            test: /\.scss$/,
            use: [
                MiniCssExtractPlugin.loader,
                'css-loader',
                'sass-loader',
            ],
        }]
    },

    resolve: {
        alias: {
            'hello-elementor': path.resolve(__dirname, 'public/themes/hello-elementor'),
        }
    }
};
